#!/bin/sh
# xvoms_init
# Script to set a password for the mysql root user and create the tables
# needed by xvoms.
# Needs to be run by root to edit /etc/my.cnf to ensure network connection.
#
# ensure networking enabled
if [ "$(id -u)" != "0" ] ; then
   echo Skipping edit of /etc/my.cnf
else
   echo " - Mysqld configuration (accept network connection)"

   #
   # Enable TCP networking by commenting-out the 'skip-networking' keyword
   # Ensure only stong password hashes are stored by disabling 'old_passwords'
   #

   perl -pi -e "s/(^skip[_-]networking)/#\1/" /etc/my.cnf  
   perl -pi -e "s/(^old[_-]passwords)/#\1/" /etc/my.cnf  

   #
   # this requires root or user running mysqld, e.g. mysql
   #

   service mysqld restart
fi


echo " - Create xvoms database entry and password"

# Always load default data to ensure admin account created

load_test=1

export PATH=/sbin:/usr/sbin:/usr/bin:$PATH

# check if service mysqld is running
service mysqld status > /dev/null 2> /dev/null
if [ $? != 0 ] ; then
   echo Error: service mysqld is not running or not installed
   exit 1
fi

oldmodes=$(stty -g)
stty -echo
echo -n "Enter password for MySQL root user:"

read rootpass
echo
if [ -z ${rootpass} ]; then
  echo "Please enter a non-null root password."
  stty $oldmodes
  exit 1
fi
# does this password work? If so don't need to set
echo quit | mysql -u root --password=${rootpass} 2> /dev/null
if [ $? == 1 ]; then
  # try and set password
  echo -n "Retype password for MySQL root user:"
  read rootpass2
  echo
  stty $oldmodes
  if [ "${rootpass}" != "${rootpass2}" ]; then
    echo Error: passwords do not match
    exit 1
  fi
  if [ -z ${rootpass} ]; then
    echo "Please enter a non-null root password."
    exit 1
  fi
  mysqladmin -u root password ${rootpass} 2> /dev/null
  if [ $? == 1 ]; then
     echo Error: 'Failed to set mysql root password - may be already set'
     exit 1
  fi
fi

stty $oldmodes

# check data available
sdir=/usr/share/xvoms/scripts
ddir=/usr/share/xvoms/data
if [ ! -e ${sdir} ]; then
   echo Error: Can not find sql setup scripts directory
   exit 1
fi

# create tables and populate them # Do this with default data
#mysql -u root --password=${rootpass}  < ${sdir}/setup.sql
#if [ $? != 0 ]; then
#  echo Error: Failed to set up SQL tables
#  exit 1
#fi

if [ ${load_test} == 1 ]; then
   echo "Loading default data into xvoms database"
   mysql -u root --password=${rootpass} < ${ddir}/xvoms.txt
fi
mysql -u root --password=${rootpass}  < ${sdir}/dbuser.sql
mysql -u root --password=${rootpass}  mysql < ${sdir}/sethost.sql
#
# Set passwords for admin and example-user
#
echo "Setting passwords for users 'admin' and 'example-user'..."
/usr/share/xvoms/bin/xvoms_changepass.pl admin example-user

